<?php

namespace Litecms\BannedIP\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\BannedIP\Http\Requests\BannedIPRequest;
use Litecms\BannedIP\Interfaces\BannedIPRepositoryInterface;
use Litecms\BannedIP\Models\BannedIP;

/**
 * Resource controller class for banned_i_p.
 */
class BannedIPResourceController extends BaseController
{

    /**
     * Initialize banned_i_p resource controller.
     *
     * @param type BannedIPRepositoryInterface $banned_i_p
     *
     * @return null
     */
    public function __construct(BannedIPRepositoryInterface $banned_i_p)
    {
        parent::__construct();
        $this->repository = $banned_i_p;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\BannedIP\Repositories\Criteria\BannedIPResourceCriteria::class);
    }

    /**
     * Display a list of banned_i_p.
     *
     * @return Response
     */
    public function index(BannedIPRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\BannedIP\Repositories\Presenter\BannedIPPresenter::class)
                ->$function();
        }

        $banned_i_ps = $this->repository->paginate();

        return $this->response->title(trans('banned_i_p::banned_i_p.names'))
            ->view('banned_i_p::banned_i_p.index', true)
            ->data(compact('banned_i_ps'))
            ->output();
    }

    /**
     * Display banned_i_p.
     *
     * @param Request $request
     * @param Model   $banned_i_p
     *
     * @return Response
     */
    public function show(BannedIPRequest $request, BannedIP $banned_i_p)
    {

        if ($banned_i_p->exists) {
            $view = 'banned_i_p::banned_i_p.show';
        } else {
            $view = 'banned_i_p::banned_i_p.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('banned_i_p::banned_i_p.name'))
            ->data(compact('banned_i_p'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new banned_i_p.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BannedIPRequest $request)
    {

        $banned_i_p = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('banned_i_p::banned_i_p.name')) 
            ->view('banned_i_p::banned_i_p.create', true) 
            ->data(compact('banned_i_p'))
            ->output();
    }

    /**
     * Create new banned_i_p.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BannedIPRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $banned_i_p                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('banned_i_p::banned_i_p.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('banned_i_p/banned_i_p/' . $banned_i_p->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/banned_i_p/banned_i_p'))
                ->redirect();
        }

    }

    /**
     * Show banned_i_p for editing.
     *
     * @param Request $request
     * @param Model   $banned_i_p
     *
     * @return Response
     */
    public function edit(BannedIPRequest $request, BannedIP $banned_i_p)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('banned_i_p::banned_i_p.name'))
            ->view('banned_i_p::banned_i_p.edit', true)
            ->data(compact('banned_i_p'))
            ->output();
    }

    /**
     * Update the banned_i_p.
     *
     * @param Request $request
     * @param Model   $banned_i_p
     *
     * @return Response
     */
    public function update(BannedIPRequest $request, BannedIP $banned_i_p)
    {
        try {
            $attributes = $request->all();

            $banned_i_p->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('banned_i_p::banned_i_p.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('banned_i_p/banned_i_p/' . $banned_i_p->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('banned_i_p/banned_i_p/' . $banned_i_p->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the banned_i_p.
     *
     * @param Model   $banned_i_p
     *
     * @return Response
     */
    public function destroy(BannedIPRequest $request, BannedIP $banned_i_p)
    {
        try {

            $banned_i_p->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('banned_i_p::banned_i_p.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('banned_i_p/banned_i_p/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('banned_i_p/banned_i_p/' . $banned_i_p->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple banned_i_p.
     *
     * @param Model   $banned_i_p
     *
     * @return Response
     */
    public function delete(BannedIPRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('banned_i_p::banned_i_p.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('banned_i_p/banned_i_p'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/banned_i_p/banned_i_p'))
                ->redirect();
        }

    }

    /**
     * Restore deleted banned_i_ps.
     *
     * @param Model   $banned_i_p
     *
     * @return Response
     */
    public function restore(BannedIPRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('banned_i_p::banned_i_p.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/banned_i_p/banned_i_p'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/banned_i_p/banned_i_p/'))
                ->redirect();
        }

    }

}
